/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.sourcery.management;

import java.io.File;

/**
 * A {@link ResourceManager} that saves to and loads from a {@link File}
 *
 * @author Cruz Bishop
 * @since 1.0.0.0
 * @param <T> The type of class to load
 */
public abstract class FileResourceManager<T> extends ResourceManager<T> {
    
    /**
     * Creates a new {@link FileResourceManager}
     * 
     * @param file The {@link File} to use
     * @since 1.0.0.0
     */
    public FileResourceManager(File file) {
        super();
        this.file = file;
    }
    
    /**
     * The {@link File} to use
     * 
     * @since 1.0.0.0
     */
    private File file;
    
    /**
     * Gets the {@link File} to use
     * 
     * @return The {@link File}
     * @since 1.0.0.0
     */
    public File getFile() {
        return this.file;
    }
    
    /**
     * Sets the {@link File} to use
     * 
     * @param file The {@link File}
     * @since 1.0.0.0
     */
    public void setFile(File file) {
        this.file = file;
    }
    
}
